## [AKShare](https://github.com/akfamily/akshare) 债券数据

### 债券基础信息

![](https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/readme/index/bond_stock_index.png)

上图是利用 [AKShare](https://github.com/akfamily/akshare) 的 **get_bond_bank** 函数获取的中国银行间
交易商协会发布的债券数据来绘制的, 可以在上面明确看出近几个月发债规模急速上升.

#### 债券查询

接口: bond_info_cm

目标地址: https://www.chinamoney.com.cn/chinese/scsjzqxx/

描述: 中国外汇交易中心暨全国银行间同业拆借中心-数据-债券信息-信息查询

输入参数

| 名称          | 类型  | 描述                                                      |
|-------------|-----|---------------------------------------------------------|
| bond_name   | str | bond_name=""; 默认为空                                      |
| bond_code   | str | bond_code=""; 默认为空                                      |
| bond_issue  | str | bond_issue=""; 默认为空, 通过 ak.bond_info_cm_query() 查询相关参数  |
| bond_type   | str | bond_type=""; 默认为空, 通过 ak.bond_info_cm_query() 查询相关参数   |
| coupon_type | str | coupon_type=""; 默认为空, 通过 ak.bond_info_cm_query() 查询相关参数 |
| issue_year  | str | issue_year=""; 默认为空                                     |
| underwriter | str | underwriter=""; 默认为空, 通过 ak.bond_info_cm_query() 查询相关参数 |
| grade       | str | grade=""; 默认为空                                          |

输出参数

| 名称       | 类型     | 描述  |
|----------|--------|-----|
| 债券简称     | object | -   |
| 债券代码     | object | -   |
| 发行人/受托机构 | object | -   |
| 债券类型     | object | -   |
| 发行日期     | object | -   |
| 最新债项评级   | object | -   |
| 查询代码     | object | -   |

接口示例

```python
import akshare as ak

bond_info_cm_df = ak.bond_info_cm(bond_name="", bond_code="", bond_issue="", bond_type="短期融资券", coupon_type="零息式", issue_year="2019", grade="A-1", underwriter="重庆农村商业银行股份有限公司")
print(bond_info_cm_df)
```

数据示例

```
          债券简称       债券代码      发行人/受托机构   债券类型        发行日期 最新债项评级        查询代码
0   19渝机电CP002  041900474  重庆机电控股(集团)公司  短期融资券  2019-12-16    A-1  06006vznk4
1   19渝机电CP001  041900229  重庆机电控股(集团)公司  短期融资券  2019-06-13    A-1  786875qtsi
2  19万林投资CP001  041900126  重庆万林投资发展有限公司  短期融资券  2019-03-25    A-1  695327xh9n
```

#### 债券基础信息

接口: bond_info_detail_cm

目标地址: https://www.chinamoney.com.cn/chinese/zqjc/?bondDefinedCode=egfjh08154

描述: 中国外汇交易中心暨全国银行间同业拆借中心-数据-债券信息-信息查询-债券详情

输入参数

| 名称     | 类型  | 描述                                                 |
|--------|-----|----------------------------------------------------|
| symbol | str | symbol="19万林投资CP001"; 通过 ak.bond_info_cm() 查询 债券简称 |

输出参数

| 名称    | 类型     | 描述  |
|-------|--------|-----|
| name  | object | -   |
| value | object | -   |

接口示例

```python
import akshare as ak

bond_info_detail_cm_df = ak.bond_info_detail_cm(symbol="19万林投资CP001")
print(bond_info_detail_cm_df)
```

数据示例

```
        name                       value
0        bondFullName  重庆万林投资发展有限公司2019年度第一期短期融资券
1     bondDefinedCode                  695327xh9n
2            bondName                 19万林投资CP001
3            bondCode                   041900126
4            isinCode                         ---
..                ...                         ...
59        chrgngMthds                         ---
60             crdtEv                         ---
61     brchStlmntMthd                         ---
62  rgstrtnCnfrmtnDay                         ---
63             inptTp                           0
[64 rows x 2 columns]
```

### 债券基础名词

#### 固定收益证券

是指持券人可以在特定的时间内取得固定的收益并预先知道取得收益的数量和时间, 如固定利率债券、优先股股票等.

#### 国债

国债又称国家公债, 是国家以其信用为基础, 按照债券的一般原则, 通过向社会发行债券筹集资金所形成的债权债务关系. 国债是中央政府为筹集财政资金而发行的一种政府债券, 由中央政府向投资者出具的、承诺在一定时期支付利息和到期偿还本金的债权债务凭证, 由于国债的发行主体是国家, 所以它具有最高的信用度, 被公认为是最安全的投资工具.

### 上交所债券

#### 债券现券市场概览

接口: bond_cash_summary_sse

目标地址: http://bond.sse.com.cn/data/statistics/overview/bondow/

描述: 上登债券信息网-市场数据-市场统计-市场概览-债券现券市场概览

限量: 单次返回指定交易日的债券现券市场概览数据

输入参数

| 名称   | 类型  | 描述              |
|------|-----|-----------------|
| date | str | date='20200111' |

输出参数

| 名称   | 类型      | 描述       |
|------|---------|----------|
| 债券现货 | object  | -        |
| 托管只数 | int64   | -        |
| 托管市值 | float64 | 注意单位: 亿元 |
| 托管面值 | float64 | 注意单位: 亿元 |
| 数据日期 | object  | -        |

接口示例

```python
import akshare as ak

bond_cash_summary_sse_df = ak.bond_cash_summary_sse(date='20210111')
print(bond_cash_summary_sse_df)
```

数据示例

```
        债券现货   托管只数       托管市值       托管面值        数据日期
0         国债    193    6815.47    6758.46  2021-01-11
1        地方债   5317    6713.69    6709.22  2021-01-11
2        金融债     19     989.76     970.70  2021-01-11
3        企业债   2233    7497.15    7433.93  2021-01-11
4  非公开发行公司债券   4974   43857.61   44191.15  2021-01-11
5       可交换债     57    1352.85    1280.10  2021-01-11
6   公开发行公司债券   3393   46382.41   46644.57  2021-01-11
7     可转换公司债    142    3655.79    3179.81  2021-01-11
8     资产支持证券   4141   14838.03   14829.47  2021-01-11
9         合计  20469  132102.75  131997.40  2021-01-11
```

#### 债券成交概览

接口: bond_deal_summary_sse

目标地址: http://bond.sse.com.cn/data/statistics/overview/turnover/

描述: 上登债券信息网-市场数据-市场统计-市场概览-债券成交概览

限量: 单次返回指定交易日的债券成交概览数据

输入参数

| 名称   | 类型  | 描述              |
|------|-----|-----------------|
| date | str | date='20200104' |

输出参数

| 名称     | 类型      | 描述       |
|--------|---------|----------|
| 债券类型   | object  | -        |
| 当日成交笔数 | int64   | -        |
| 当日成交金额 | float64 | 注意单位: 万元 |
| 当年成交笔数 | int64   | -        |
| 当年成交金额 | float64 | 注意单位: 万元 |
| 数据日期   | object  | -        |

接口示例

```python
import akshare as ak

bond_summary_sse_df = ak.bond_deal_summary_sse(date='20210104')
print(bond_summary_sse_df)
```

数据示例

```
        债券类型  当日成交笔数 当日成交金额  当年成交笔数  当年成交金额  数据日期
0      记账式国债    3685   363349.44    3685   363349.44  2021-01-04
1      地方政府债      11    81284.62      11    81284.62  2021-01-04
2        金融债     568    11075.26     568    11075.26  2021-01-04
3        企业债     234   124537.76     234   124537.76  2021-01-04
4    中小企业私募债     298   802906.69     298   802906.69  2021-01-04
5    公开发行公司债    1570  1442430.80    1570  1442430.80  2021-01-04
6   非公开发行公司债      26    66038.67      26    66038.67  2021-01-04
7        可转债  923863  1566929.29  923863  1566929.29  2021-01-04
8       可交换债    3962    26873.67    3962    26873.67  2021-01-04
9        分离债       0        0.00       0        0.00  2021-01-04
10  企业资产支持证券      44   215197.41      44   215197.41  2021-01-04
11  信贷资产支持证券       0        0.00       0        0.00  2021-01-04
12      其他债券       0        0.00       0        0.00  2021-01-04
13        合计  934261  4700623.60  934261  4700623.60  2021-01-04
```

### 债券基础数据

#### 银行间市场债券发行基础数据

接口: get_bond_bank

目标地址: http://zhuce.nafmii.org.cn/fans/publicQuery/manager

描述: 银行间债券市场数据

限量: 单次最大 20 行, 建议用循环获取数据

输入参数

| 名称       | 类型  | 描述                                        |
|----------|-----|-------------------------------------------|
| page_num | int | 默认参数 page_num=1, 输入想要提取的页码, 多页提取请用 for 循环 |

输出参数

| 名称               | 类型    | 描述                |
|------------------|-------|-------------------|
| firstIssueAmount | str   | 金额(亿元)            |
| isReg            | str   | 是否注册, 显示为: 备案或者注册 |
| regFileName      | str   | 债券名称              |
| regPrdtType      | str   | 品种                |
| releaseTime      | float | 更新时间              |
| projPhase        | float | 项目阶段              |

接口示例

```python
import akshare as ak

get_bond_bank_df = ak.get_bond_bank(page_num=1)
print(get_bond_bank_df)
```

数据示例

```
   firstIssueAmount isReg                               regFileName  \
0                 9     1    淮南市产业发展(集团)有限公司关于发行2019年度第一期短期融资券的注册报告
1                10     1          光大嘉宝股份有限公司关于发行2019年度第一期中期票据的注册报告
2                15     1           西安高新控股有限公司关于发行2019年第二期中期票据的注册报告
3                10     1          启迪控股股份有限公司关于发行2019年度第一期中期票据的注册报告
4                 5     2  云南华电金沙江中游水电开发有限公司关于发行2019年度第二期短期融资券的注册报告
5                 5     1       南京栖霞山旅游发展有限公司关于发行2019年度第一期中期票据的注册报告
6                14     2   徐工集团工程机械有限公司关于发行2019年度第二期短期融资券的注册报告(备案)
7                10     1      天津临港投资控股有限公司关于发行2019年度第一期超短期融资券的注册报告
8                 2     1          中德联合集团有限公司关于发行2019年度第一期中期票据的注册报告
9                10     1             浙江恒逸集团有限公司2019年度第七期超短期融资券注册报告
10                5     1        西王集团有限公司关于发行2019-2021年度超短期融资券的注册报告
11                5     1   荆州市城市建设投资开发有限公司关于注册发行2019年度第二期中期票据的注册报告
12               10     1       招商局通商融资租赁有限公司关于发行2019年度第一期中期票据的注册报告
13               15     1          中国旅游集团有限公司关于发行2019年度第四期中期票据的注册报告
14               22     1     天津市保障住房建设投资有限公司关于发行2019年度第二期中期票据的注册报告
15                5     1     余姚市城市建设投资发展有限公司关于发行2019年度第四期中期票据的注册报告
16                5     2       四川蓝光发展股份有限公司关于发行2019年度第二期短期融资券的注册报告
17                5     1      连云港市工业投资集团有限公司关于发行2019年度第二期中期票据的注册报告
18               10     1        德州德达城市建设投资运营有限公司2019年度第一期中期票据的注册报告
19                5     2   厦门经济特区房地产开发集团有限公司关于发行2019年度第一期中期票据的注册报告

   regPrdtType          releaseTime projPhase
0           CP  2019-10-12 00:00:00        20
1          MTN  2019-10-12 00:00:00        20
2          MTN  2019-10-12 00:00:00        20
3          MTN  2019-10-12 00:00:00        20
4           CP  2019-10-12 00:00:00        60
5          MTN  2019-10-12 00:00:00        20
6           CP  2019-10-12 00:00:00        60
7          SCP  2019-10-12 00:00:00        20
8          MTN  2019-10-12 00:00:00        20
9          SCP  2019-10-12 00:00:00        30
10         SCP  2019-10-12 00:00:00        20
11         MTN  2019-10-12 00:00:00        20
12         MTN  2019-10-12 00:00:00        20
13          PN  2019-10-12 00:00:00        20
14         MTN  2019-10-12 00:00:00        20
15         MTN  2019-10-12 00:00:00        20
16          CP  2019-10-12 00:00:00        20
17         MTN  2019-10-12 00:00:00        20
18         MTN  2019-10-12 00:00:00        20
19          PN  2019-10-12 00:00:00        60
```

### 中国债券市场行情数据

#### 现券市场做市报价

接口: bond_spot_quote

目标地址: http://www.chinamoney.com.cn/chinese/mkdatabond/

描述: 中国外汇交易中心暨全国银行间同业拆借中心-市场数据-市场行情-债券市场行情-现券市场做市报价

限量: 单次返回所有数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称    | 类型      | 描述      |
|-------|---------|---------|
| 报价机构  | object  |         |
| 债券简称  | object  |         |
| 买入净价  | float64 | 注意单位: 元 |
| 卖出净价  | float64 | 注意单位: 元 |
| 买入收益率 | float64 | 注意单位: % |
| 卖出收益率 | float64 | 注意单位: % |

接口示例

```python
import akshare as ak

bond_spot_quote_df = ak.bond_spot_quote()
print(bond_spot_quote_df)
```

数据示例

```
     报价机构       债券简称  买入净价 卖出净价  买入收益率 卖出收益率
0   星展银行(中国)  21进出10  100.34  102.44  3.335  3.0750
1   星展银行(中国)  20农发08  101.88  102.87  2.882  2.5901
2   星展银行(中国)  20农发07  100.57  101.26  2.640  2.1401
3   星展银行(中国)  20农发02   99.79  100.03  2.400  2.1701
4   星展银行(中国)  20进出13  101.00  101.71  2.641  2.1605
5   星展银行(中国)  20进出05  100.40  101.02  2.790  2.5700
6       平安证券  22进出05   98.38   99.40  2.970  2.7409
7       平安证券  22国开01   99.85   99.95  2.265  2.1401
8       平安证券  20农发08  101.88  102.90  2.882  2.5820
9       平安证券  20农发02   99.82  100.00  2.370  2.2000
10      平安证券  20进出05  100.48  101.02  2.760  2.5700
11      平安证券  20国开12  101.63  102.27  2.820  2.6200
12      平安证券  20国开08  100.21  100.85  2.820  2.6150
13      平安证券  20国开07  100.71  100.95  2.479  2.3074
14      平安证券  18进出03  102.35  102.52  2.295  2.1000
```

#### 现券市场成交行情

接口: bond_spot_deal

目标地址: http://www.chinamoney.com.cn/chinese/mkdatabond/

描述: 中国外汇交易中心暨全国银行间同业拆借中心-市场数据-市场行情-债券市场行情-现券市场成交行情

限量: 单次返回所有即期数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称    | 类型      | 描述       |
|-------|---------|----------|
| 债券简称  | object  | -        |
| 成交净价  | float64 | 注意单位: 元  |
| 最新收益率 | float64 | 注意单位: %  |
| 涨跌    | float64 | 注意单位: BP |
| 加权收益率 | float64 | 注意单位: %  |
| 交易量   | float64 | 注意单位: 亿  |

接口示例

```python
import akshare as ak

bond_spot_deal_df = ak.bond_spot_deal()
print(bond_spot_deal_df)
```

数据示例

```
                  债券简称   成交净价 最新收益率   涨跌  加权收益率  交易量
0                21国开15   99.97  3.1220 -0.20  3.1211  1860.0000
1              21附息国债17  100.42  2.8404  0.04  2.8354   328.0649
2                22国开05   99.34  3.0775 -1.18  3.0846   284.2000
3                21国开08  100.00  2.8275  0.25  2.8200   263.0018
4                21国开10  101.57  3.2099  0.74  3.2008   218.3000
                 ...     ...     ...   ...     ...        ...
2129       21历下控股PPN002  100.98  3.5297  7.37  3.5297     0.0200
2130             20国开20  105.62  3.4800 -0.10  3.4800     0.0130
2131        19赣高速MTN001  102.62  2.8287 -0.65  2.8287     0.0110
2132  21苏交通MTN003(权益出资)  101.35  2.8250 -0.65  2.8250     0.0110
2133         19汇金MTN012  101.96  2.8006 -0.65  2.8006     0.0110
```

#### 国债及其他债券收益率曲线

接口: bond_china_yield

目标地址: http://yield.chinabond.com.cn/cbweb-pbc-web/pbc/historyQuery?startDate=2019-02-07&endDate=2020-02-04&gjqx=0&qxId=ycqx&locale=cn_ZH

描述: 中国债券信息网-国债及其他债券收益率曲线

限量: 单次返回所有指定日期间 start_date 到 end_date 需要小于一年的所有数据

输入参数

| 名称         | 类型  | 描述                                                          |
|------------|-----|-------------------------------------------------------------|
| start_date | str | start_date="20190204", 指定开始日期; start_date 到 end_date 需要小于一年 |
| end_date   | str | end_date="20200204", 指定结束日期; start_date 到 end_date 需要小于一年   |

输出参数

| 名称   | 类型      | 描述  |
|------|---------|-----|
| 曲线名称 | object  |     |
| 日期   | object  |     |
| 3月   | float64 |     |
| 6月   | float64 |     |
| 1年   | float64 |     |
| 3年   | float64 |     |
| 5年   | float64 |     |
| 7年   | float64 |     |
| 10年  | float64 |     |
| 30年  | float64 |     |

接口示例

```python
import akshare as ak

bond_china_yield_df = ak.bond_china_yield(start_date="20210201", end_date="20220201")
print(bond_china_yield_df)
```

数据示例

```
                    曲线名称          日期      3月  ...      7年     10年     30年
0      中债中短期票据收益率曲线(AAA)  2021-02-01  3.2000  ...  3.9929  4.1465     NaN
1    中债商业银行普通债收益率曲线(AAA)  2021-02-01  3.1085  ...  3.8172  3.9554  4.5813
2              中债国债收益率曲线  2021-02-01  2.4501  ...  3.1725  3.1712  3.7342
3              中债国债收益率曲线  2021-02-02  2.4001  ...  3.1829  3.1862  3.7415
4      中债中短期票据收益率曲线(AAA)  2021-02-02  3.0242  ...  3.9707  4.1243     NaN
..                   ...         ...     ...  ...     ...     ...     ...
748  中债商业银行普通债收益率曲线(AAA)  2022-01-29  2.3008  ...  3.3258  3.4677  3.8345
749            中债国债收益率曲线  2022-01-29  1.7876  ...  2.6521  2.7013  3.2750
750    中债中短期票据收益率曲线(AAA)  2022-01-30  2.4486  ...  3.4477  3.6091     NaN
751  中债商业银行普通债收益率曲线(AAA)  2022-01-30  2.2908  ...  3.3122  3.4541  3.8209
752            中债国债收益率曲线  2022-01-30  1.7756  ...  2.6555  2.6997  3.2718
```

#### 质押式回购-成交明细

接口: bond_repo_zh_tick

目标地址: http://stockhtm.finance.qq.com/sstock/ggcx/131802.shtml

描述: 债券-质押式回购-实时行情-成交明细; 该接口暂不可用

限量: 单次返回所有指定日期的成交明细数据

输入参数

| 名称         | 类型  | 描述                          |
|------------|-----|-----------------------------|
| code       | str | code="sz131802"; 指定质押式回购    |
| trade_date | str | trade_date="20210120"; 指定日期 |

输出参数

| 名称     | 类型    | 描述            |
|--------|-------|---------------|
| 成交时间   | str   | 时间: 09:25:04; |
| 成交价格   | float |               |
| 价格变动   | float |               |
| 成交量(手) | float |               |
| 成交额(元) | float |               |
| 性质     | str   | 买卖盘标记         |

接口示例

```python
import akshare as ak

bond_repo_zh_tick_df = ak.bond_repo_zh_tick(code="sz131802", trade_date="20210120")
print(bond_repo_zh_tick_df)
```

数据示例

```
      成交时间  成交价格  价格变动  成交量(手)   成交额(元)  性质
0     09:25:04  2.40  1.17     284   284000  卖盘
1     09:30:05  2.70  0.30     985   985000  卖盘
2     09:30:27  2.70  0.00    1030  1030000  卖盘
3     09:30:30  2.70  0.00     200   200000  卖盘
4     09:30:57  2.50 -0.20     500   500000  卖盘
        ...   ...   ...     ...      ...  ..
1101  15:23:28  1.45  0.00      38    38000  卖盘
1102  15:24:55  1.45  0.00      25    25000  卖盘
1103  15:26:06  1.45  0.00      34    34000  卖盘
1104  15:26:54  1.45  0.00      59    59000  卖盘
1105  15:30:05  1.45  0.00      80    80000  卖盘
```

### 沪深债券

#### 实时行情数据

接口: bond_zh_hs_spot

目标地址: http://vip.stock.finance.sina.com.cn/mkt/#hs_z

描述: 新浪财经-债券-沪深债券-实时行情数据

限量: 单次返回所有沪深债券的实时行情数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称  | 类型      | 描述      |
|-----|---------|---------|
| 代码  | object  | -       |
| 名称  | object  | -       |
| 最新价 | float64 | -       |
| 涨跌额 | float64 | -       |
| 涨跌幅 | float64 | -       |
| 买入  | float64 | -       |
| 卖出  | float64 | -       |
| 昨收  | float64 | -       |
| 今开  | float64 | -       |
| 最高  | float64 | -       |
| 最低  | float64 | -       |
| 成交量 | int64   | 注意单位: 手 |
| 成交额 | int64   | 注意单位: 万 |

接口示例

```python
import akshare as ak
bond_zh_hs_spot_df = ak.bond_zh_hs_spot()
print(bond_zh_hs_spot_df)
```

数据示例

```
       代码       名称      最新价    涨跌额  ...  最高       最低     成交量       成交额
0     sh010107   21国债⑺  100.010    0.0  ...    0.000    0.000       0         0
1     sh010303   03国债⑶  101.520  -0.01  ...  101.540  101.480   33080   3358085
2     sh010504   05国债⑷  105.380  -0.11  ...  105.550  105.250    1020    107622
3     sh010512   05国债⑿  100.050    0.0  ...    0.000    0.000       0         0
4     sh010609   06国债⑼  100.000    0.0  ...    0.000    0.000       0         0
        ...     ...      ...    ...  ...      ...      ...     ...       ...
7961  sz149689  21国际P1    0.000  0.000  ...    0.000    0.000       0         0
7962  sz149691  21粤海03  100.214  0.214  ...  100.214  100.214  500000  50107000
7963  sz149692  21广新D1    0.000  0.000  ...    0.000    0.000       0         0
7964  sz149693  21东华01    0.000  0.000  ...    0.000    0.000       0         0
7965  sz149694  21金桂01    0.000  0.000  ...    0.000    0.000       0         0
```

#### 历史行情数据

接口: bond_zh_hs_daily

目标地址: http://money.finance.sina.com.cn/bond/quotes/sh019315.html(示例)

描述: 新浪财经-债券-沪深债券-历史行情数据, 历史数据按日频率更新

限量: 单次返回具体某个沪深转债的所有历史行情数据

输入参数

| 名称     | 类型  | 描述                |
|--------|-----|-------------------|
| symbol | str | symbol="sh010107" |

输出参数

| 名称     | 类型      | 描述  |
|--------|---------|-----|
| date   | object  | -   |
| open   | float64 | -   |
| high   | float64 | -   |
| low    | float64 | -   |
| close  | float64 | -   |
| volume | float64 | -   |

接口示例

```python
import akshare as ak
bond_zh_hs_daily_df = ak.bond_zh_hs_daily(symbol="sh010107")
print(bond_zh_hs_daily_df)
```

数据示例

```
            date     open     high      low    close    volume
0     2001-08-20  101.255  102.835  101.255  102.695  60765500
1     2001-08-21  102.743  103.213  102.683  103.133  19927710
2     2001-08-22  103.332  103.402  103.022  103.222  13132740
3     2001-08-23  103.260  103.300  103.080  103.110   9544530
4     2001-08-24  103.158  103.158  102.908  102.958   7068480
          ...      ...      ...      ...      ...       ...
4801  2021-07-26  100.030  100.060  100.000  100.010   1757900
4802  2021-07-27  100.010  100.030  100.000  100.030   1635540
4803  2021-07-28  100.010  100.030  100.000  100.020   1425370
4804  2021-07-29  100.000  100.020  100.000  100.010    244680
4805  2021-07-30  100.000  100.010   99.990  100.010    150850
```

### 沪深可转债

#### 实时行情数据

接口: bond_zh_hs_cov_spot

目标地址: http://vip.stock.finance.sina.com.cn/mkt/#hskzz_z

描述: 新浪财经-沪深可转债数据

限量: 单次返回所有沪深可转债的实时行情数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称  | 类型  | 描述    |
|-----|-----|-------|
| -   | -   | 不逐一列出 |

接口示例

```python
import akshare as ak

bond_zh_hs_cov_spot_df = ak.bond_zh_hs_cov_spot()
print(bond_zh_hs_cov_spot_df)
```

数据示例

```
       symbol    code  name    trade  ... pb mktcap nmc turnoverratio
0    sh110031  110031  航信转债  126.760  ...  0      0   0             0
1    sh110033  110033  国贸转债  114.480  ...  0      0   0             0
2    sh110034  110034  九州转债  114.320  ...  0      0   0             0
3    sh110038  110038  济川转债  108.100  ...  0      0   0             0
4    sh110041  110041  蒙电转债  115.900  ...  0      0   0             0
..        ...     ...   ...      ...  ... ..    ...  ..           ...
222  sz128089  128089  麦米转债  129.410  ...  0      0   0             0
223  sz128090  128090  汽模转2  138.402  ...  0      0   0             0
224  sz128091  128091  新天转债  113.227  ...  0      0   0             0
225  sz128092  128092  唐人转债  113.500  ...  0      0   0             0
226  sz128093  128093  百川转债  109.305  ...  0      0   0             0
```

#### 历史行情数据-日频

接口: bond_zh_hs_cov_daily

目标地址: http://biz.finance.sina.com.cn/suggest/lookup_n.php?q=sh110048(示例)

描述: 新浪财经-历史行情数据，日频率更新, 新上的标的需要次日更新数据

限量: 单次返回具体某个沪深可转债的所有历史行情数据

输入参数

| 名称     | 类型  | 描述                |
|--------|-----|-------------------|
| symbol | str | symbol="sh113542" |

输出参数

| 名称     | 类型      | 描述  |
|--------|---------|-----|
| date   | object  | -   |
| open   | float64 | -   |
| high   | float64 | -   |
| low    | float64 | -   |
| close  | float64 | -   |
| volume | float64 | -   |

接口示例

```python
import akshare as ak

bond_zh_hs_cov_daily_df = ak.bond_zh_hs_cov_daily(symbol="sh113542")
print(bond_zh_hs_cov_daily_df)
```

数据示例

```
          date     open     high      low    close    volume
0   2021-04-23  130.000  130.000  130.000  130.000  18364266
1   2021-04-26  130.353  133.880  125.110  130.010  86109443
2   2021-04-27  129.000  130.846  128.400  129.600  18207663
3   2021-04-28  129.100  131.663  128.903  130.770  14677269
4   2021-04-29  130.690  133.150  130.560  131.208  11569344
5   2021-04-30  131.400  134.160  131.250  133.214   8609423
6   2021-05-06  133.214  134.500  131.580  132.460   6222345
7   2021-05-07  132.500  133.230  130.731  130.900   4990454
8   2021-05-10  131.000  131.401  129.480  130.542   4241153
9   2021-05-11  130.259  131.440  129.680  130.677   5419358
10  2021-05-12  130.370  130.958  130.080  130.520   3014035
45  2021-07-01  149.000  149.980  143.160  143.500   5807049
46  2021-07-02  143.500  143.555  142.000  142.200   3810009
47  2021-07-05  142.200  143.300  140.600  142.412   2403004
48  2021-07-06  142.590  143.270  141.641  142.450   2898619
49  2021-07-07  141.560  146.500  141.560  145.200   4625750
50  2021-07-08  146.490  150.051  146.490  147.633   8435651
51  2021-07-09  147.300  150.000  147.020  149.400   4707946
52  2021-07-12  152.900  154.300  149.991  153.000   9523429
53  2021-07-13  152.680  153.516  149.880  150.899   3874366
54  2021-07-14  150.150  152.990  150.022  150.600   3202497
55  2021-07-15  150.600  154.423  150.400  153.910   4630852
```

#### 历史行情数据-分时

接口: bond_zh_hs_cov_min

目标地址: https://quote.eastmoney.com/concept/sz128039.html

描述: 东方财富网-可转债-分时行情

限量: 单次返回指定可转债、指定频率、复权调整和时间区间的分时数据, 其中 1 分钟数据只返回近 1 个交易日数据且不复权; 其余 period 只能获取近期的数据

输入参数

| 名称         | 类型  | 描述                                                                                                  |
|------------|-----|-----------------------------------------------------------------------------------------------------|
| symbol     | str | symbol='sz123106'; 转债代码                                                                             |
| period     | str | period='5'; choice of {'1', '5', '15', '30', '60'}; 其中 1 分钟数据返回近 1 个交易日数据且不复权                       |
| adjust     | str | adjust=''; choice of {'', 'qfq', 'hfq'}; '': 不复权, 'qfq': 前复权, 'hfq': 后复权, 其中 1 分钟数据返回近 1 个交易日数据且不复权 |
| start_date | str | start_date="1979-09-01 09:32:00"; 日期时间; 默认返回所有数据                                                    |
| end_date   | str | end_date="2222-01-01 09:32:00"; 日期时间; 默认返回所有数据                                                      |

输出参数-1分钟数据

| 名称  | 类型      | 描述      |
|-----|---------|---------|
| 时间  | object  | -       |
| 开盘  | float64 | -       |
| 收盘  | float64 | -       |
| 最高  | float64 | -       |
| 最低  | float64 | -       |
| 成交量 | float64 | 注意单位: 手 |
| 成交额 | float64 | -       |
| 最新价 | float64 | -       |

接口示例-1分钟数据

```python
import akshare as ak

bond_zh_hs_cov_min_df = ak.bond_zh_hs_cov_min(symbol="sz123124", period='1', adjust='', start_date="1979-09-01 09:32:00", end_date="2222-01-01 09:32:00")
print(bond_zh_hs_cov_min_df)
```

数据示例-1分钟数据

```
                      时间       开盘       收盘  ...  成交量       成交额       最新价
0    2021-11-02 09:30:00  120.000  120.000  ...  195  234000.0  120.0000
1    2021-11-02 09:31:00  119.980  119.889  ...  390  467090.0  119.8855
2    2021-11-02 09:32:00  119.889  119.741  ...  115  137730.0  119.8657
3    2021-11-02 09:33:00  119.900  120.100  ...  542  649973.0  119.9286
4    2021-11-02 09:34:00  120.100  120.022  ...   83   99593.0  119.9326
..                   ...      ...      ...  ...  ...       ...       ...
236  2021-11-02 14:56:00  120.018  120.060  ...  150  180075.0  120.3760
237  2021-11-02 14:57:00  120.060  120.095  ...  289  346535.0  120.3732
238  2021-11-02 14:58:00  120.095  120.095  ...    0       0.0  120.3732
239  2021-11-02 14:59:00  120.095  120.095  ...    0       0.0  120.3732
240  2021-11-02 15:00:00  120.099  120.099  ...  198  237796.0  120.3719
```

输出参数-其他

| 名称  | 类型      | 描述      |
|-----|---------|---------|
| 时间  | object  | -       |
| 开盘  | float64 | -       |
| 收盘  | float64 | -       |
| 最高  | float64 | -       |
| 最低  | float64 | -       |
| 涨跌幅 | float64 | 注意单位: % |
| 涨跌额 | float64 | -       |
| 成交量 | float64 | 注意单位: 手 |
| 成交额 | float64 | -       |
| 振幅  | float64 | 注意单位: % |
| 换手率 | float64 | 注意单位: % |

接口示例-其他

```python
import akshare as ak

bond_zh_hs_cov_min_df = ak.bond_zh_hs_cov_min(symbol="sz123124", period='5', adjust='hfq', start_date="2021-09-01 09:32:00", end_date="2021-09-06 09:32:00")
print(bond_zh_hs_cov_min_df)
```

数据示例-其他

```
              时间       开盘       收盘  ...         成交额    振幅   换手率
0     2021-09-10 09:35:00  128.048  130.164  ...  12380872.0  1.78  1.83
1     2021-09-10 09:40:00  130.306  129.720  ...  11514303.0  1.12  1.70
2     2021-09-10 09:45:00  129.800  129.781  ...  12926171.0  0.87  1.90
3     2021-09-10 09:50:00  129.815  129.700  ...   9881294.0  0.53  1.45
4     2021-09-10 09:55:00  129.682  129.868  ...   7237449.0  0.51  1.07
                   ...      ...      ...  ...         ...   ...   ...
1483  2021-11-02 14:40:00  119.979  119.940  ...    462174.0  0.04  0.07
1484  2021-11-02 14:45:00  119.940  119.960  ...    582866.0  0.05  0.09
1485  2021-11-02 14:50:00  119.960  120.000  ...    394934.0  0.08  0.06
1486  2021-11-02 14:55:00  120.002  120.050  ...    634978.0  0.07  0.10
1487  2021-11-02 15:00:00  120.018  120.099  ...    764406.0  0.10  0.12
```

#### 历史行情数据-盘前分时

接口: bond_zh_hs_cov_pre_min

目标地址: https://quote.eastmoney.com/concept/sz128039.html

描述: 东方财富网-可转债-分时行情-盘前分时

限量: 单次返回指定可转债在最近交易日的盘前分时数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称  | 类型      | 描述      |
|-----|---------|---------|
| 时间  | object  | -       |
| 开盘  | float64 | -       |
| 收盘  | float64 | -       |
| 最高  | float64 | -       |
| 最低  | float64 | -       |
| 成交量 | float64 | 注意单位: 手 |
| 成交额 | float64 | -       |
| 最新价 | float64 | -       |

接口示例

```python
import akshare as ak

bond_zh_hs_cov_pre_min_df = ak.bond_zh_hs_cov_pre_min(symbol="sh113570")
print(bond_zh_hs_cov_pre_min_df)
```

数据示例

```
                 时间      开盘     收盘  ...  成交量     成交额    最新价
0    2022-07-27 09:15:00  128.14  128.14  ...    0       0.0  128.1400
1    2022-07-27 09:16:00  128.14  128.14  ...    0       0.0  127.9800
2    2022-07-27 09:17:00  128.03  128.03  ...    0       0.0  127.9800
3    2022-07-27 09:18:00  128.30  128.30  ...    0       0.0  127.9800
4    2022-07-27 09:19:00  128.30  128.30  ...    0       0.0  127.9800
..                   ...     ...     ...  ...  ...       ...       ...
131  2022-07-27 11:26:00  128.89  128.89  ...   37   47688.0  128.4185
132  2022-07-27 11:27:00  128.83  128.71  ...   27   34765.0  128.4193
133  2022-07-27 11:28:00  128.71  128.80  ...   21   27043.0  128.4201
134  2022-07-27 11:29:00  128.80  128.81  ...   85  109487.0  128.4232
135  2022-07-27 11:30:00  128.81  128.78  ...    7    9016.0  128.4235
```

#### 可转债数据一览表

接口: bond_zh_cov

目标地址: http://data.eastmoney.com/kzz/default.html

描述: 东方财富网-数据中心-新股数据-可转债数据一览表

限量: 单次返回当前交易时刻的所有可转债数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称          | 类型      | 描述       |
|-------------|---------|----------|
| 债券代码        | object  | -        |
| 债券简称        | object  | -        |
| 申购日期        | object  | -        |
| 申购代码        | object  | -        |
| 申购上限        | float64 | 注意单位: 万元 |
| 正股代码        | object  | -        |
| 正股简称        | object  | -        |
| 正股价         | float64 | -        |
| 转股价         | float64 | -        |
| 转股价值        | float64 | -        |
| 债现价         | float64 | -        |
| 转股溢价率       | float64 | 注意单位: %  |
| 原股东配售-股权登记日 | float64 | -        |
| 原股东配售-每股配售额 | object  | -        |
| 发行规模        | float64 | 注意单位: 亿元 |
| 中签号发布日      | object  | -        |
| 中签率         | float64 | 注意单位: %  |
| 上市时间        | object  | -        |

接口示例

```python
import akshare as ak

bond_zh_cov_df = ak.bond_zh_cov()
print(bond_zh_cov_df)
```

数据示例

```
     债券代码   债券简称  申购日期  ...    中签号发布日   中签率        上市时间
0    113628   晨丰转债  2021-08-23  ...  2021-08-25  0.001960         NaT
1    123124   晶瑞转2  2021-08-16  ...  2021-08-18  0.002896         NaT
2    127045   牧原转债  2021-08-16  ...  2021-08-18  0.014138         NaT
3    127044   蒙娜转债  2021-08-16  ...  2021-08-18  0.001882         NaT
4    118002   天合转债  2021-08-13  ...  2021-08-17  0.010599  2021-09-01
..      ...    ...         ...  ...         ...       ...         ...
590  110227   赤化转债  2007-10-10  ...  2007-10-16  0.158854  2007-10-23
591  126006  07深高债  2007-10-09  ...  2007-10-15  0.290304  2007-10-30
592  110971   恒源转债  2007-09-24  ...  2007-09-28  5.311774  2007-10-12
593  110567   山鹰转债  2007-09-05  ...  2007-09-11  0.496391  2007-09-17
594  110026   中海转债  2007-07-02  ...  2007-07-06  1.333453  2007-07-12
```

#### 可转债详情

接口: bond_zh_cov_info

目标地址: https://data.eastmoney.com/kzz/detail/123121.html

描述: 东方财富网-数据中心-新股数据-可转债详情

限量: 单次返回指定 symbol 的可转债详情数据

输入参数

| 名称     | 类型  | 描述                                                                                  |
|--------|-----|-------------------------------------------------------------------------------------|
| symbol | str | symbol="123121"; 可转债代码                                                              |
| symbol | str | indicator="基本信息"; choice of {"基本信息", "中签号", "筹资用途", "重要日期"}, 其中 "可转债重要条款" 在 "基本信息中" |

输出参数

| 名称   | 类型     | 描述        |
|------|--------|-----------|
| 债券代码 | object | 返回 67 个字段 |

接口示例

```python
import akshare as ak

bond_zh_cov_info_df = ak.bond_zh_cov_info(symbol="123121", indicator="基本信息")
print(bond_zh_cov_info_df)
```

数据示例

```
  SECURITY_CODE   SECUCODE TRADE_MARKET  ... IS_CONVERT_STOCK IS_REDEEM IS_SELLBACK
0        123121  123121.SZ       CNSESZ  ...                是         是           是
```

#### 可转债比价表

接口: bond_cov_comparison

目标地址: http://quote.eastmoney.com/center/fullscreenlist.html#convertible_comparison

描述: 东方财富网-行情中心-债券市场-可转债比价表

限量: 单次返回当前交易时刻的所有可转债比价数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称    | 类型      | 描述      |
|-------|---------|---------|
| 序号    | int32   | -       |
| 转债代码  | object  | -       |
| 转债名称  | object  | -       |
| 转债最新价 | object  | -       |
| 转债涨跌幅 | object  | 注意单位: % |
| 正股代码  | object  | -       |
| 正股名称  | object  | -       |
| 正股最新价 | object  | -       |
| 正股涨跌幅 | object  | 注意单位: % |
| 转股价   | object  | -       |
| 转股价值  | object  | -       |
| 转股溢价率 | object  | 注意单位: % |
| 纯债溢价率 | object  | 注意单位: % |
| 回售触发价 | object  | -       |
| 强赎触发价 | object  | -       |
| 到期赎回价 | object  | -       |
| 纯债价值  | float64 | -       |
| 开始转股日 | object  | -       |
| 上市日期  | object  | -       |
| 申购日期  | object  | -       |

接口示例

```python
import akshare as ak

bond_cov_comparison_df = ak.bond_cov_comparison()
print(bond_cov_comparison_df)
```

数据示例

```
      序号    转债代码   转债名称 转债最新价 转债涨跌幅  ...  到期赎回价      纯债价值     开始转股日 上市日期      申购日期
0      1  123114   三角转债     -     -  ...  115.0   81.5083  20211130    -  20210525
1      2  111000   起帆转债     -     -  ...  115.0   81.1652  20211129    -  20210524
2      3  127034   绿茵转债     -     -  ...  113.0   80.5937  20211111    -  20210430
3      4  113624   正川转债     -     -  ...  115.0   93.3750  20211108    -  20210428
4      5  113048   晶科转债     -     -  ...  112.0   89.8588  20211029    -  20210423
..   ...     ...    ...   ...   ...  ...    ...       ...       ...  ...       ...
370  371  110806  中闽定02     -     -  ...      -  100.6112  20210722    -         -
371  372  110805  中闽定01     -     -  ...      -   96.2539         -    -         -
372  373  110804  国泰定02     -     -  ...      -   91.1144  20210301    -         -
373  374  110802  继峰定02     -     -  ...      -   95.7982  20201224    -         -
374  375  110801  继峰定01     -     -  ...      -   95.7854         -    -         -
```

#### 可转债价值分析

接口: bond_zh_cov_value_analysis

目标地址: https://data.eastmoney.com/kzz/detail/113527.html

描述: 东方财富网-行情中心-新股数据-可转债数据-可转债价值分析

限量: 单次返回所有可转债价值分析数据

输入参数

| 名称     | 类型  | 描述                     |
|--------|-----|------------------------|
| symbol | str | symbol="113527"; 可转债代码 |

输出参数

| 名称    | 类型      | 描述      |
|-------|---------|---------|
| 日期    | object  | -       |
| 收盘价   | float64 | 注意单位: 元 |
| 纯债价值  | float64 | 注意单位: 元 |
| 转股价值  | float64 | 注意单位: 元 |
| 纯债溢价率 | float64 | 注意单位: % |
| 转股溢价率 | float64 | 注意单位: % |

接口示例

```python
import akshare as ak

bond_zh_cov_value_analysis_df = ak.bond_zh_cov_value_analysis(symbol="113527")
print(bond_zh_cov_value_analysis_df)
```

数据示例

```
      日期     收盘价      纯债价值      转股价值    纯债溢价率    转股溢价率
0    2019-01-24     NaN   90.186522   98.195187  10.881313   1.837985
1    2019-01-25     NaN   90.045626   98.729947  11.054811   1.286391
2    2019-01-28     NaN   90.100390   97.593583  10.987310   2.465753
3    2019-01-29     NaN   90.105909   94.585561  10.980512   5.724382
4    2019-01-30     NaN   90.006260   94.184492  11.103384   6.174592
..          ...     ...         ...         ...        ...        ...
766  2022-03-24  123.46  107.178436  102.871795  15.191082  20.013460
767  2022-03-25  122.83  107.241827  103.076923  14.535535  19.163433
768  2022-03-28  123.37  107.300045  102.564103  14.976652  20.285750
769  2022-03-29  122.37  107.319545  101.025641  14.023964  21.127665
770  2022-03-30  122.75  107.335419  102.358974  14.361132  19.921092
```

#### 可转债溢价率分析

接口: bond_zh_cov_value_analysis

目标地址: https://data.eastmoney.com/kzz/detail/113527.html

描述: 东方财富网-行情中心-新股数据-可转债数据-可转债溢价率分析

限量: 单次返回所有可转债溢价率分析数据

输入参数

| 名称     | 类型  | 描述                     |
|--------|-----|------------------------|
| symbol | str | symbol="113527"; 可转债代码 |

输出参数

| 名称    | 类型      | 描述      |
|-------|---------|---------|
| 日期    | object  | -       |
| 收盘价   | float64 | 注意单位: 元 |
| 纯债价值  | float64 | 注意单位: 元 |
| 转股价值  | float64 | 注意单位: 元 |
| 纯债溢价率 | float64 | 注意单位: % |
| 转股溢价率 | float64 | 注意单位: % |

接口示例

```python
import akshare as ak

bond_zh_cov_value_analysis_df = ak.bond_zh_cov_value_analysis(symbol="113527")
print(bond_zh_cov_value_analysis_df)
```

数据示例

```
      日期     收盘价      纯债价值      转股价值    纯债溢价率    转股溢价率
0    2019-01-24     NaN   90.186522   98.195187  10.881313   1.837985
1    2019-01-25     NaN   90.045626   98.729947  11.054811   1.286391
2    2019-01-28     NaN   90.100390   97.593583  10.987310   2.465753
3    2019-01-29     NaN   90.105909   94.585561  10.980512   5.724382
4    2019-01-30     NaN   90.006260   94.184492  11.103384   6.174592
..          ...     ...         ...         ...        ...        ...
766  2022-03-24  123.46  107.178436  102.871795  15.191082  20.013460
767  2022-03-25  122.83  107.241827  103.076923  14.535535  19.163433
768  2022-03-28  123.37  107.300045  102.564103  14.976652  20.285750
769  2022-03-29  122.37  107.319545  101.025641  14.023964  21.127665
770  2022-03-30  122.75  107.335419  102.358974  14.361132  19.921092
```

### 可转债实时数据-集思录

接口: bond_cb_jsl

目标地址: https://app.jisilu.cn/data/cbnew/#cb

描述: 集思录可转债实时数据，包含行情数据（涨跌幅，成交量和换手率等）及可转债基本信息（转股价，溢价率和到期收益率等）

限量: 单次返回当前交易时刻的所有数据

输入参数

| 名称     | 类型  | 描述                                                 |
|--------|-----|----------------------------------------------------|
| cookie | str | cookie=''; 此处输入您的集思录 cookie 就可以获取完整数据，否则只能返回前 30 条 |

1. 需要查看的链接为：https://app.jisilu.cn/data/cbnew/cb_list/?___jsl=LST___t=1628070841431
2. 需要复制的 Cookie 为：![](https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/data/data_jsl/jsl_cookie.png)

输出参数

| 名称       | 类型      | 描述       |
|----------|---------|----------|
| 代码       | object  | -        |
| 转债名称     | object  | -        |
| 现价       | float64 | -        |
| 涨跌幅      | float64 | 注意单位: %  |
| 正股代码     | object  | -        |
| 正股名称     | object  | -        |
| 正股价      | float64 | -        |
| 正股涨跌     | float64 | 注意单位: %  |
| 正股PB     | float64 | -        |
| 转股价      | float64 | -        |
| 转股价值     | float64 | -        |
| 转股溢价率    | float64 | 注意单位: %  |
| 双低       | float64 | -        |
| 下修条件     | object  | -        |
| 评级       | object  | -        |
| 回售触发价    | float64 | -        |
| 强赎触发价    | float64 | -        |
| 转债流通市值占比 | float64 | 注意单位: %  |
| 到期时间     | object  | -        |
| 剩余年限     | float64 | -        |
| 剩余规模     | float64 | 注意单位: 亿元 |
| 成交额      | float64 | 注意单位: 万元 |
| 换手率      | float64 | 注意单位: %  |
| 到期税前收益   | float64 | 注意单位: %  |

接口示例

```python
import akshare as ak

bond_cb_jsl_df = ak.bond_cb_jsl(cookie="您的集思录 cookie")
print(bond_cb_jsl_df)
```

数据示例

```
     代码    转债名称       现价    涨跌幅  ...     剩余规模        成交额      换手率  到期税前收益
0   128107    交科转债  118.880 -10.35  ...   12.716   68094.28    43.12     NaN
1   123086    海兰转债  162.324  -2.02  ...    4.351  105652.91   145.27   -6.00
2   113059    福莱转债  100.000   0.00  ...   40.000       0.00     0.00    2.72
3   123070    鹏辉转债  215.600  -4.19  ...    5.573   81800.27    66.09  -13.53
4   132018  G三峡EB1  137.681  -0.05  ...  145.082    1381.18     0.07  -11.74
5   127013    创维转债  129.710  -5.70  ...    9.771   26434.23    20.48   -3.75
6   110071    湖盐转债  135.840  -2.28  ...    7.197   15466.24    15.49   -4.06
7   127027    靖远转债  134.500  -2.81  ...   22.035   29722.26     9.78   -3.47
8   128046    利尔转债  174.843  -4.57  ...    7.748    9269.04     6.66  -17.38
9   128111    中矿转债  701.004   6.65  ...    1.368  673699.48   697.00  -35.22
10  113615    金诚转债  167.960  -1.46  ...    8.661    9143.38     6.22   -7.73
11  123092    天壕转债  173.780  -4.63  ...    4.142   11082.89    15.00   -7.72
12  113541    荣晟转债  123.450 -11.20  ...    1.500   34078.68   179.14   -2.46
13  127064    杭氧转债  100.000   0.00  ...   11.370       0.00     0.00    2.02
14  113568    新春转债  152.880  -3.71  ...    2.431   25261.33    66.37   -5.59
15  113548    石英转债  528.170   0.16  ...    0.876  131160.27   279.28  -34.96
16  127043    川恒转债  150.000  -4.94  ...   11.587   55685.45    31.24   -4.11
17  113534    鼎胜转债  204.480  -7.16  ...    4.038   16674.56    19.30  -18.77
18  128106    华统转债  151.756  -8.34  ...    2.893    9884.68    21.99   -7.59
19  113025    明泰转债  338.620  -5.80  ...   10.148   35762.33    10.09  -31.90
20  128128    齐翔转2  144.797   0.55  ...    6.805   45316.71    44.83   -5.39
21  128141    旺能转债  133.000  -1.46  ...   12.702    4668.07     2.75   -3.23
22  127040    国泰转债  124.400  -2.16  ...   42.578   10016.21     1.87   -1.98
23  113585    寿仙转债  184.860  -4.01  ...    1.003    9808.89    51.83  -10.85
24  123146    中环转2  100.000   0.00  ...    8.640       0.00     0.00    3.32
25  127007    湖广转债  172.880   1.52  ...    3.698  877324.96  1331.64  -19.23
26  123083    朗新转债  167.502  -1.98  ...    5.483   21433.09    22.72   -8.10
27  113630    赛伍转债  132.900  -3.58  ...    6.998   13524.53    14.21   -1.82
28  110061    川投转债  135.930  -1.57  ...   39.616    2727.34     0.50   -5.96
29  113537    文灿转债  241.400  -2.73  ...    1.405   91138.43   255.62  -20.75
```

### 可转债强赎

接口: bond_cb_redeem_jsl

目标地址: https://www.jisilu.cn/data/cbnew/#redeem

描述: 集思录可转债-强赎

限量: 单次返回所有数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称    | 类型      | 描述      |
|-------|---------|---------|
| 代码    | object  | -       |
| 名称    | object  | -       |
| 现价    | float64 | -       |
| 正股代码  | object  | -       |
| 正股名称  | object  | -       |
| 规模    | float64 | 注意单位: 亿 |
| 剩余规模  | float64 | -       |
| 转股起始日 | object  | -       |
| 转股价   | float64 | -       |
| 强赎触发比 | int64   | 注意单位: % |
| 强赎触发价 | float64 | -       |
| 正股价   | float64 | -       |
| 强赎价   | float64 | -       |
| 强赎天计数 | object  | -       |
| 强赎条款  | object  | -       |
| 强赎状态  | object  | -       |

接口示例

```python
import akshare as ak

bond_cb_redeem_jsl_df = ak.bond_cb_redeem_jsl()
print(bond_cb_redeem_jsl_df)
```

数据示例

```
         代码    名称       现价  ...       强赎天计数                           强赎条款   强赎状态
0    123084  高澜转债  144.600  ...  25/15 | 30  如果公司股票在任意连续三十个交易日中至少十五个交易日...  已公告强赎
1    123070  鹏辉转债  369.543  ...  30/20 | 30  如果公司A股股票连续30个交易日中至少有20个交易日...  已公告强赎
2    113599  嘉友转债  139.980  ...  22/15 | 30  如果公司股票连续三十个交易日中至少有十五个交易日的收...  已公告强赎
3    113630  赛伍转债  131.550  ...  20/15 | 30  如果公司 A 股股票连续 30 个交易日中至少有15...  已公告强赎
4    123073  同和转债  148.460  ...  25/20 | 30  如果公司A股股票连续三十个交易日中至少有二十个交易日...  已公告强赎
..      ...   ...      ...  ...         ...                            ...    ...
439  113639  华正转债  113.270  ...   0/15 | 30  如果公司股票在任何连续三十个交易日中至少十五个交易日...
440  123136  城市转债  244.200  ...   0/15 | 30  如果公司股票在任意连续三十个交易日中至少有十五个交易...
441  123137  锦浪转债  166.490  ...   0/15 | 30  如果公司股票在任意连续三十个交易日中至少十五个交易日...
442  123138  丝路转债  144.700  ...   0/15 | 30  如果公司股票在任何连续三十个交易日中至少十五个交易日...
443  113646  永吉转债  253.950  ...   0/15 | 30  公司股票在任何连续三十个交易日中至少有十五个交易日的...
```

### 集思录可转债等权指数

接口: bond_cb_index_jsl

目标地址: https://www.jisilu.cn/web/data/cb/index

描述: 可转债-集思录可转债等权指数

限量: 单次返回所有历史数据数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称                  | 类型      | 描述        |
|---------------------|---------|-----------|
| price_dt            | object  | 日期        |
| price               | float64 | 指数        |
| amount              | float64 | 剩余规模(亿元)  |
| volume              | float64 | 成交额(亿元)   |
| count               | int64   | 数量        |
| increase_val        | float64 | 涨跌        |
| increase_rt         | float64 | 涨幅        |
| avg_price           | float64 | 平均价格(元)   |
| mid_price           | float64 | 中位数价格(元)  |
| mid_convert_value   | float64 | 中位数转股价值   |
| avg_dblow           | float64 | 平均双底      |
| avg_premium_rt      | float64 | 平均溢价率     |
| mid_premium_rt      | float64 | 中位数溢价率    |
| avg_ytm_rt          | float64 | 平均收益率     |
| turnover_rt         | float64 | 换手率       |
| price_90            | int64   | >90       |
| price_90_100        | int64   | 90~100    |
| price_100_110       | int64   | 100~110   |
| price_110_120       | int64   | 110~120   |
| price_120_130       | int64   | 120~130   |
| price_130           | int64   | >130      |
| increase_rt_90      | float64 | >90涨幅     |
| increase_rt_90_100  | float64 | 90~100涨幅  |
| increase_rt_100_110 | float64 | 100~110涨幅 |
| increase_rt_110_120 | float64 | 110~120涨幅 |
| increase_rt_120_130 | float64 | 120~130涨幅 |
| increase_rt_130     | float64 | >130涨幅    |
| idx_price           | float64 | 沪深300指数   |
| idx_increase_rt     | float64 | 沪深300指数涨幅 |

接口示例

```python
import akshare as ak

bond_cb_index_jsl_df = ak.bond_cb_index_jsl()
print(bond_cb_index_jsl_df)
```

数据示例

```
        price_dt     price  ...  idx_price  idx_increase_rt
0     2017-12-29  1000.000  ...   4030.850             0.30
1     2018-01-02  1008.831  ...   4087.400             1.40
2     2018-01-03  1018.808  ...   4111.390             0.59
3     2018-01-04  1024.344  ...   4128.810             0.42
4     2018-01-05  1034.655  ...   4138.750             0.24
...          ...       ...  ...        ...              ...
1146  2022-09-19  1997.231  ...   3928.000            -0.12
1147  2022-09-20  2012.310  ...   3932.836             0.12
1148  2022-09-21  2019.373  ...   3903.735            -0.74
1149  2022-09-22  2017.313  ...   3869.344            -0.88
1150  2022-09-23  1998.653  ...   3856.021            -0.34
```

### 可转债转股价格调整记录-集思录

接口: bond_cb_adj_logs_jsl

目标地址: https://app.jisilu.cn/data/cbnew/#cb; 点击带红色星号的转股价会弹出转股价调整记录

描述: 集思录-单个可转债的转股价格-调整记录

限量: 返回当前时刻该可转债的所有转股价格调整记录

输入参数

| 名称     | 类型  | 描述                     |
|--------|-----|------------------------|
| symbol | str | symbol="128013"; 可转债代码 |

输出参数

| 名称       | 类型      | 描述  |
|----------|---------|-----|
| 转债名称     | object  | -   |
| 股东大会日    | object  | -   |
| 下修前转股价   | float64 | -   |
| 下修后转股价   | float64 | -   |
| 新转股价生效日期 | object  | -   |
| 下修底价     | float64 | -   |

接口示例

```python
import akshare as ak

bond_convert_adj_logs_jsl_df = ak.bond_cb_adj_logs_jsl(symbol="128013")
print(bond_convert_adj_logs_jsl_df)
```

数据示例

```
   转债名称  股东大会日  下修前转股价 下修后转股价 新转股价生效日期 下修底价
0  洪涛转债  2021-02-23    3.10    2.32  2021-02-24  2.32
1  洪涛转债  2020-06-29    8.00    3.12  2020-06-30  3.12
2  洪涛转债  2019-11-20    9.97    8.00  2019-11-21  3.10
```

### 全球债券行情数据

接口: bond_investing_global

目标地址: https://cn.investing.com/rates-bonds

描述: 获取全球政府债券行情与收益率; 该接口需要通过代理访问, 由于涉及国家和债券多(**近1000**个债券)具体参见[国家-债券目录](https://cn.investing.com/rates-bonds/world-government-bonds?maturity_from=10&maturity_to=310)

具体的调用方式可以参照:

1. 先查询指数所在的国家名称;
2. 复制网页上国家名称(推荐复制), 如 **中国**;
3. 复制所显示的具体债券名称(推荐复制, 如果英文中间有空格, 也需要保留空格), 如 **中国1年期国债**; 也可以调用 **ak.bond_investing_global_country_name_url(country="美国")** 获取需要国家的具体指数名称
4. 在安装 [AKShare](https://github.com/akfamily/akshare) 后输入, 如 **ak.bond_investing_global(country="中国", index_name="中国1年期国债", period="每周", start_date="2000-01-01", end_date="2020-06-06")**;
5. 稍后就可以获得所需数据; 由于服务器在国外, 如访问失败, 请稍后重试.

限量: 单次返回某一个国家的具体某一个指数, 建议用 for 循环获取多个国家的多个指数, 注意不要大量获取, 以免给对方服务器造成压力!

输入参数

| 名称         | 类型  | 描述                                                                                    |
|------------|-----|---------------------------------------------------------------------------------------|
| country    | str | country="中国"                                                                          |
| index_name | str | index_name="中国1年期国债"; 可以通过 ak.bond_investing_global_country_name_url(country="美国") 获取 |
| period     | str | period="每月"; choice of {"每日", "每周", "每月"}                                             |
| start_date | str | start_date='20000101'                                                                 |
| end_date   | str | end_date='20191017'                                                                   |

输出参数

| 名称  | 类型    | 描述           |
|-----|-------|--------------|
| 日期  | str   | 日期索引         |
| 收盘  | float | 收盘           |
| 开盘  | float | 开盘           |
| 高   | float | 高            |
| 低   | float | 低            |
| 交易量 | str   | 涨跌幅; 注意单位: % |

接口示例

```python
import akshare as ak

bond_investing_global_df = ak.bond_investing_global(country="中国", index_name="中国1年期国债", period="每周", start_date="20000101", end_date="20200606")
print(bond_investing_global_df)
```

数据示例

```
            收盘     开盘      高      低    涨跌幅
日期
2020-05-31  1.720  1.543  1.720  1.543   6.77
2020-05-24  1.611  1.500  1.611  1.500   7.40
2020-05-17  1.500  1.400  1.500  1.400  21.95
2020-05-10  1.230  1.217  1.300  1.217   0.99
2020-05-03  1.218  1.210  1.227  1.180   6.56
           ...    ...    ...    ...    ...
2002-07-07  2.020  2.020  2.020  2.020  -0.30
2002-06-30  2.026  2.026  2.026  2.026   3.21
2002-06-23  1.963  1.963  1.963  1.963   1.19
2002-06-16  1.940  1.940  1.940  1.940   0.88
2002-06-09  1.923  1.923  1.923  1.923   0.52
```

### 国债期货可交割券相关指标

接口: bond_futures_deliverable_coupons

目标地址: http://www.csindex.com.cn/zh-CN/bond-valuation/bond-futures-deliverable-coupons-related-indicators

描述: 国债期货可交割券相关指标

限量: 只能返回近一年的数据

输入参数

| 名称         | 类型  | 描述                    |
|------------|-----|-----------------------|
| trade_date | str | trade_date="20200922" |

输出参数

| 名称     | 类型      | 描述         |
|--------|---------|------------|
| 日期     | object  | -          |
| 银行间代码  | object  | -          |
| 上交所代码  | object  | -          |
| 深交所代码  | object  | -          |
| 合约代码   | object  | -          |
| 中证估值   | float64 | 注意单位: (净价) |
| 基差     | float64 | -          |
| 发票价格   | float64 | -          |
| 隐含回购利率 | float64 | 注意单位: %    |

接口示例

```python
import akshare as ak
bond_futures_deliverable_coupons_df = ak.bond_futures_deliverable_coupons(trade_date="20210823")
print(bond_futures_deliverable_coupons_df)
```

数据示例

```
    日期    银行间代码  上交所代码   深交所代码    合约代码     中证估值      基差      发票价格  隐含回购利率
0   20210823   180028  19610  101828  TF2106  100.649 -1.4011  104.5379   62.45
1   20210823   200013  19643  102013  TF2106   99.775 -1.4758  103.9564   61.54
2   20210823   180011  19593  101811   T2106  103.191 -1.1420  105.5360    0.21
3   20210823   200016  19646  102016   T2106  102.316 -0.0230  103.3880    0.03
4   20210823   200006  19632  102006   T2106   98.336  0.5850   98.5950   -0.07
5   20210823   190006  19616  101906   T2106  103.071  0.9120  103.1780   -0.12
6   20210823  2000004  19639  102064   T2106   99.977  0.8740   99.5690   -0.12
7   20210823  2000003  19637  102063   T2106   99.608  1.1860   99.0420   -0.17
8   20210823   180019  19601  101819   T2106  105.114  1.5730  103.8200   -0.22
9   20210823   190015  19625  101915   T2106  103.098  1.9810  102.1030   -0.29
10  20210823   180027  19609  101827   T2106  105.596  3.8090  102.8040   -0.57
```

### 收盘收益率曲线历史数据

接口: bond_china_close_return

目标地址: http://www.chinamoney.com.cn/chinese/bkcurvclosedyhis/?bondType=CYCC000&reference=1

描述: 收盘收益率曲线历史数据, 该接口只能获取近 3 个月的数据，且每次获取的数据不超过 1 个月

输入参数

| 名称         | 类型  | 描述                                                                       |
|------------|-----|--------------------------------------------------------------------------|
| symbol     | str | symbol="政策性金融债(进出口行)"; 通过网页查询或调用 **ak.bond_china_close_return_map()** 获取 |
| period     | str | period: str = "1"; 期限间隔, choice of {'0.1', '0.5', '1'}                   |
| start_date | str | start_date="20200830"; 结束日期, 结束日期和开始日期不要超过 1 个月                          |
| end_date   | str | end_date="20200930"; 结束日期, 结束日期和开始日期不要超过 1 个月                            |

输出参数

| 名称    | 类型      | 描述  |
|-------|---------|-----|
| 日期    | object  | -   |
| 期限    | float64 | -   |
| 到期收益率 | float64 | -   |
| 即期收益率 | float64 | -   |
| 远期收益率 | float64 | -   |

接口示例

```python
import akshare as ak

bond_china_close_return_df = ak.bond_china_close_return(symbol="政策性金融债(进出口行)", period="1", start_date="20220104", end_date="20220104")
print(bond_china_close_return_df)
```

数据示例

```
            日期      期限   到期收益率   即期收益率   远期收益率
0   2022-01-04   0.083  2.1613  2.1613     NaN
1   2022-01-04   0.250  2.1026  2.1026     NaN
2   2022-01-04   0.500  2.3043  2.3043     NaN
3   2022-01-04   0.750  2.2995  2.2995     NaN
4   2022-01-04   1.000  2.3522  2.3522  2.6613
5   2022-01-04   2.000  2.5047  2.5066  2.8486
6   2022-01-04   3.000  2.6162  2.6205  3.0910
7   2022-01-04   4.000  2.7298  2.7379  3.3340
8   2022-01-04   5.000  2.8434  2.8569  3.5295
9   2022-01-04   6.000  2.9489  2.9687  3.7663
10  2022-01-04   7.000  3.0543  3.0822  3.3544
11  2022-01-04   8.000  3.0876  3.1162  3.4313
12  2022-01-04   9.000  3.1209  3.1512  3.5100
13  2022-01-04  10.000  3.1542  3.1870  3.7787
14  2022-01-04  11.000  3.2018  3.2407  3.8982
```

### 中美国债收益率

接口: bond_zh_us_rate

目标地址: http://data.eastmoney.com/cjsj/zmgzsyl.html

描述: 东方财富网-数据中心-经济数据-中美国债收益率历史数据

限量: 返回所有交易日的数据

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称            | 类型      | 描述  |
|---------------|---------|-----|
| 日期            | object  | -   |
| 中国国债收益率2年     | float64 | -   |
| 中国国债收益率5年     | float64 | -   |
| 中国国债收益率10年    | float64 | -   |
| 中国国债收益率30年    | float64 | -   |
| 中国国债收益率10年-2年 | float64 | -   |
| 中国GDP年增率      | float64 | -   |
| 美国国债收益率2年     | float64 | -   |
| 美国国债收益率5年     | float64 | -   |
| 美国国债收益率10年    | float64 | -   |
| 美国国债收益率30年    | float64 | -   |
| 美国国债收益率10年-2年 | float64 | -   |
| 美国GDP年增率      | float64 | -   |

接口示例

```python
import akshare as ak

bond_zh_us_rate_df = ak.bond_zh_us_rate()
print(bond_zh_us_rate_df)
```

数据示例

```
       日期  中国国债收益率2年  中国国债收益率5年  ...  美国国债收益率30年  美国国债收益率10年-2年  美国GDP年增率
0     1990-12-19        NaN        NaN  ...        8.19           0.79       NaN
1     1990-12-20        NaN        NaN  ...        8.22           0.80       NaN
2     1990-12-21        NaN        NaN  ...        8.28           0.81       NaN
3     1990-12-24        NaN        NaN  ...        8.36           0.85       NaN
4     1990-12-26        NaN        NaN  ...        8.30           0.88       NaN
...          ...        ...        ...  ...         ...            ...       ...
8128  2022-02-28     2.2558     2.5105  ...        2.17           0.39       NaN
8129  2022-03-01     2.2686     2.5419  ...        2.11           0.41       NaN
8130  2022-03-02     2.2847     2.5651  ...        2.24           0.36       NaN
8131  2022-03-03     2.3098     2.5958  ...        2.24           0.33       NaN
8132  2022-03-04        NaN     2.5705  ...        2.16            NaN       NaN
```

### 债券发行

#### 国债发行

接口: bond_treasure_issue_cninfo

目标地址: http://webapi.cninfo.com.cn/#/thematicStatistics

描述: 巨潮资讯-数据中心-专题统计-债券报表-债券发行-国债发行

输入参数

| 名称         | 类型  | 描述                    |
|------------|-----|-----------------------|
| start_date | str | start_date="20210911" |
| end_date   | str | end_date="20211110"   |

输出参数

| 名称     | 类型      | 描述       |
|--------|---------|----------|
| 债券代码   | object  | -        |
| 债券简称   | object  | -        |
| 发行起始日  | object  | -        |
| 发行终止日  | object  | -        |
| 计划发行总量 | float64 | 注意单位: 亿元 |
| 实际发行总量 | float64 | 注意单位: 亿元 |
| 发行价格   | float64 | 注意单位: 元  |
| 单位面值   | int64   | 注意单位: 元  |
| 缴款日    | object  | -        |
| 增发次数   | int64   | -        |
| 交易市场   | object  | -        |
| 发行方式   | object  | -        |
| 发行对象   | object  | -        |
| 公告日期   | object  | -        |
| 债券名称   | object  | -        |

接口示例

```python
import akshare as ak

bond_treasure_issue_cninfo_df = ak.bond_treasure_issue_cninfo(start_date="20210910", end_date="20211109")
print(bond_treasure_issue_cninfo_df)
```

数据示例

```
        债券代码        债券简称  ...        公告日期                债券名称
0     019660      21国债12  ...  2021-09-30   2021年记账式附息(十二期)国债
1     102112      国债2112  ...  2021-09-30   2021年记账式附息(十二期)国债
2     210012    21附息国债12  ...  2021-09-30   2021年记账式附息(十二期)国债
3     210012    21附息国债12  ...  2021-09-30   2021年记账式附息(十二期)国债
4     210012    21附息国债12  ...  2021-09-30   2021年记账式附息(十二期)国债
5     210012    21附息国债12  ...  2021-09-30   2021年记账式附息(十二期)国债
6   N0323835      国债2113  ...  2021-09-30   2021年记账式附息(十三期)国债
7   N0323835      国债2113  ...  2021-09-30   2021年记账式附息(十三期)国债
8   N0323835      国债2113  ...  2021-09-30   2021年记账式附息(十三期)国债
9   N0323835      21国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
10  N0323835      21国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
11  N0323835      21国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
12  N0323835    21附息国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
13  N0323835    21附息国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
14  N0323835    21附息国债13  ...  2021-09-30   2021年记账式附息(十三期)国债
15    211709      21储蓄09  ...  2021-09-29   2021年第九期储蓄国债(电子式)
16    211710      21储蓄10  ...  2021-09-29   2021年第十期储蓄国债(电子式)
17    020445      21贴债48  ...  2021-09-26  2021年记账式贴现(四十八期)国债
18    108445      贴债2148  ...  2021-09-26  2021年记账式贴现(四十八期)国债
19    219948    21贴现国债48  ...  2021-09-26  2021年记账式贴现(四十八期)国债
20    020443      21贴债46  ...  2021-09-16  2021年记账式贴现(四十六期)国债
21    108444      贴债2146  ...  2021-09-16  2021年记账式贴现(四十六期)国债
22    219946    21贴现国债46  ...  2021-09-16  2021年记账式贴现(四十六期)国债
23    020444      21贴债47  ...  2021-09-23  2021年记账式贴现(四十七期)国债
24    108443      贴债2147  ...  2021-09-23  2021年记账式贴现(四十七期)国债
25    219947    21贴现国债47  ...  2021-09-23  2021年记账式贴现(四十七期)国债
26    019653      21国债05  ...  2021-09-10    2021年记账式附息(五期)国债
27    102105      国债2105  ...  2021-09-10    2021年记账式附息(五期)国债
28    210005    21附息国债05  ...  2021-09-10    2021年记账式附息(五期)国债
29    020442      21贴债45  ...  2021-09-16  2021年记账式贴现(四十五期)国债
30    108442      贴债2145  ...  2021-09-16  2021年记账式贴现(四十五期)国债
31    219945    21贴现国债45  ...  2021-09-16  2021年记账式贴现(四十五期)国债
32    019657      21国债09  ...  2021-09-08    2021年记账式附息(九期)国债
33    102109      国债2109  ...  2021-09-08    2021年记账式附息(九期)国债
34    210009    21附息国债09  ...  2021-09-08    2021年记账式附息(九期)国债
35    210009    21附息国债09  ...  2021-09-08    2021年记账式附息(九期)国债
36    210009    21附息国债09  ...  2021-09-08    2021年记账式附息(九期)国债
37    210009    21附息国债09  ...  2021-09-08    2021年记账式附息(九期)国债
38    019658      21国债10  ...  2021-09-08    2021年记账式附息(十期)国债
39    102110      国债2110  ...  2021-09-08    2021年记账式附息(十期)国债
40    210010    21附息国债10  ...  2021-09-08    2021年记账式附息(十期)国债
41    210010    21附息国债10  ...  2021-09-08    2021年记账式附息(十期)国债
42    210010    21附息国债10  ...  2021-09-08    2021年记账式附息(十期)国债
43    210010    21附息国债10  ...  2021-09-08    2021年记账式附息(十期)国债
44    019651      21国债03  ...  2021-09-03    2021年记账式附息(三期)国债
45    102103      国债2103  ...  2021-09-03    2021年记账式附息(三期)国债
46    210003    21附息国债03  ...  2021-09-03    2021年记账式附息(三期)国债
47  N0319386  21储蓄05(凭证)  ...  2021-09-03   2021年第五期储蓄国债(凭证式)
48  N0319387  21储蓄06(凭证)  ...  2021-09-03   2021年第六期储蓄国债(凭证式)
49    020441      21贴债44  ...  2021-09-09  2021年记账式贴现(四十四期)国债
50    108441      贴债2144  ...  2021-09-09  2021年记账式贴现(四十四期)国债
51    219944    21贴现国债44  ...  2021-09-09  2021年记账式贴现(四十四期)国债
```

#### 地方债发行

接口: bond_local_government_issue_cninfo

目标地址: http://webapi.cninfo.com.cn/#/thematicStatistics

描述: 巨潮资讯-数据中心-专题统计-债券报表-债券发行-地方债发行

输入参数

| 名称         | 类型  | 描述                    |
|------------|-----|-----------------------|
| start_date | str | start_date="20210911" |
| end_date   | str | end_date="20211110"   |

输出参数

| 名称     | 类型      | 描述       |
|--------|---------|----------|
| 债券代码   | object  | -        |
| 债券简称   | object  | -        |
| 发行起始日  | object  | -        |
| 发行终止日  | object  | -        |
| 计划发行总量 | float64 | 注意单位: 亿元 |
| 实际发行总量 | float64 | 注意单位: 亿元 |
| 发行价格   | float64 | 注意单位: 元  |
| 单位面值   | int64   | 注意单位: 元  |
| 缴款日    | object  | -        |
| 增发次数   | int64   | -        |
| 交易市场   | object  | -        |
| 发行方式   | object  | -        |
| 发行对象   | object  | -        |
| 公告日期   | object  | -        |
| 债券名称   | object  | -        |

接口示例

```python
import akshare as ak

bond_local_government_issue_cninfo_df = ak.bond_local_government_issue_cninfo(start_date="20210911", end_date="20211110")
print(bond_local_government_issue_cninfo_df)
```

数据示例

```
         债券代码  ...                                             债券名称
0    N0323869  ...                          2021年天津市地方政府再融资一般债券(八期)
1    N0323870  ...                          2021年天津市地方政府再融资专项债券(九期)
2    N0323871  ...                            2021年天津市地方政府专项债券(十四期)
3    N0323872  ...                            2021年天津市地方政府专项债券(十五期)
4    N0323873  ...                            2021年天津市地方政府专项债券(十六期)
..        ...  ...                                              ...
620    192226  ...         2021年山东省政府棚改专项债券(八期)-2021年山东省政府专项债券(四十期)
621   2105885  ...         2021年山东省政府棚改专项债券(八期)-2021年山东省政府专项债券(四十期)
622    186469  ...  2021年山东省政府支持中小银行发展专项债券(一期)-2021年山东省政府专项债券(四十一期)
623    192227  ...  2021年山东省政府支持中小银行发展专项债券(一期)-2021年山东省政府专项债券(四十一期)
624   2105886  ...  2021年山东省政府支持中小银行发展专项债券(一期)-2021年山东省政府专项债券(四十一期)
```

#### 企业债发行

接口: bond_corporate_issue_cninfo

目标地址: http://webapi.cninfo.com.cn/#/thematicStatistics

描述: 巨潮资讯-数据中心-专题统计-债券报表-债券发行-企业债发行

输入参数

| 名称         | 类型  | 描述                    |
|------------|-----|-----------------------|
| start_date | str | start_date="20210911" |
| end_date   | str | end_date="20211110"   |

输出参数

| 名称         | 类型      | 描述       |
|------------|---------|----------|
| 债券代码       | object  | -        |
| 债券简称       | object  | -        |
| 公告日期       | object  | -        |
| 交易所网上发行起始日 | object  | -        |
| 交易所网上发行终止日 | object  | -        |
| 计划发行总量     | float64 | 注意单位: 万元 |
| 实际发行总量     | float64 | 注意单位: 万元 |
| 发行面值       | float64 | -        |
| 发行价格       | int64   | 注意单位: 元  |
| 发行方式       | object  | -        |
| 发行对象       | object  | -        |
| 发行范围       | object  | -        |
| 承销方式       | object  | -        |
| 最小认购单位     | float64 | 注意单位: 万元 |
| 募资用途说明     | object  | -        |
| 最低认购额      | float64 | 注意单位: 万元 |
| 债券名称       | object  | -        |

接口示例

```python
import akshare as ak

bond_corporate_issue_cninfo_df = ak.bond_corporate_issue_cninfo(start_date="20210911", end_date="20211110")
print(bond_corporate_issue_cninfo_df)
```

数据示例

```
         债券代码       债券简称  ...       最低认购额                                       债券名称
0      188842     21临城01  ...  10000000.0           2021年临沂城市建设投资集团有限公司公开发行公司债券(第一期)
1    N0323809  21潍坊滨城债01  ...      1000.0                 2021年潍坊滨城建设集团有限公司公司债券(第一期)
2      188793     21中林01  ...  10000000.0        2021年中国林业集团有限公司面向专业投资者公开发行公司债券(第一期)
3      188845     21大宁02  ...         NaN  2021年上海大宁资产经营(集团)有限公司面向专业投资者公开发行公司债券(第二期)
4     2180409   21湖州申太02  ...   1000000.0                 2021年湖州申太建设发展有限公司公司债券(第二期)
..        ...        ...  ...         ...                                        ...
207   2180376      21赣城债  ...   1000000.0                  2021年赣州城市开发投资集团有限责任公司公司债券
208    188702     21正奇01  ...  10000000.0        2021年正奇控股股份有限公司面向专业投资者公开发行公司债券(第一期)
209    188738     21舟城02  ...  10000000.0    2021年舟山海城建设投资集团有限公司面向专业投资者公开发行公司债券(第二期)
210    188758     21一航Y2  ...   1000000.0         2021年中交第一航务工程局有限公司公开发行可续期公司债券(第二期)
211    149632     21碧地03  ...   1000000.0       2021年碧桂园地产集团有限公司面向专业投资者公开发行公司债券(第三期)
```

#### 可转债发行

接口: bond_cov_issue_cninfo

目标地址: http://webapi.cninfo.com.cn/#/thematicStatistics

描述: 巨潮资讯-数据中心-专题统计-债券报表-债券发行-可转债发行

输入参数

| 名称         | 类型  | 描述                    |
|------------|-----|-----------------------|
| start_date | str | start_date="20210913" |
| end_date   | str | end_date="20211112"   |

输出参数

| 名称              | 类型      | 描述       |
|-----------------|---------|----------|
| 债券代码            | object  | -        |
| 债券简称            | object  | -        |
| 公告日期            | object  | -        |
| 发行起始日           | object  | -        |
| 发行终止日           | object  | -        |
| 计划发行总量          | float64 | 注意单位: 万元 |
| 实际发行总量          | float64 | 注意单位: 万元 |
| 发行面值            | int64   | 注意单位: 元  |
| 发行价格            | float64 | 注意单位: 元  |
| 发行方式            | object  | -        |
| 发行对象            | object  | -        |
| 发行范围            | object  | -        |
| 承销方式            | object  | -        |
| 募资用途说明          | object  | -        |
| 初始转股价格          | float64 | 注意单位: 元  |
| 转股开始日期          | object  | -        |
| 转股终止日期          | object  | -        |
| 网上申购日期          | object  | -        |
| 网上申购代码          | object  | -        |
| 网上申购简称          | object  | -        |
| 网上申购数量上限        | float64 | 注意单位: 万元 |
| 网上申购数量下限        | float64 | 注意单位: 万元 |
| 网上申购单位          | float64 | -        |
| 网上申购中签结果公告日及退款日 | object  | -        |
| 优先申购日           | object  | -        |
| 配售价格            | float64 | 注意单位: 元  |
| 债权登记日           | object  | -        |
| 优先申购缴款日         | object  | -        |
| 转股代码            | object  | -        |
| 交易市场            | object  | -        |
| 债券名称            | object  | -        |

接口示例

```python
import akshare as ak

bond_cov_issue_cninfo_df = ak.bond_cov_issue_cninfo(start_date="20210913", end_date="20211112")
print(bond_cov_issue_cninfo_df)
```

数据示例

```
     债券代码  债券简称        公告日期  ...    转股代码 交易市场                         债券名称
0  127046  百润转债  2021-09-25  ...  002568  深交所  上海百润投资控股集团股份有限公司公开发行可转换公司债券
1  113629  泉峰转债  2021-09-10  ...  603982  上交所  南京泉峰汽车精密技术股份有限公司公开发行可转换公司债券
```

#### 可转债转股

接口: bond_cov_stock_issue_cninfo

目标地址: http://webapi.cninfo.com.cn/#/thematicStatistics

描述: 巨潮资讯-数据中心-专题统计-债券报表-债券发行-可转债转股

输入参数

| 名称  | 类型  | 描述  |
|-----|-----|-----|
| -   | -   | -   |

输出参数

| 名称       | 类型      | 描述      |
|----------|---------|---------|
| 债券代码     | object  | -       |
| 债券简称     | object  | -       |
| 公告日期     | object  | -       |
| 转股代码     | object  | -       |
| 转股简称     | object  | -       |
| 转股价格     | float64 | 注意单位: 元 |
| 自愿转换期起始日 | object  | -       |
| 自愿转换期终止日 | object  | -       |
| 标的股票     | object  | -       |
| 债券名称     | object  | -       |

接口示例

```python
import akshare as ak

bond_cov_stock_issue_cninfo_df = ak.bond_cov_stock_issue_cninfo()
print(bond_cov_stock_issue_cninfo_df)
```

数据示例

```
       债券代码  债券简称  ...    标的股票                                债券名称
0    127046  百润转债  ...  002568         上海百润投资控股集团股份有限公司公开发行可转换公司债券
1    113629  泉峰转债  ...  603982         南京泉峰汽车精密技术股份有限公司公开发行可转换公司债券
2    123126  瑞丰转债  ...  300243   山东瑞丰高分子材料股份有限公司创业板向不特定对象发行可转换公司债券
3    123125  元力转债  ...  300174        福建元力活性炭股份有限公司向不特定对象发行可转换公司债券
4    113628  晨丰转债  ...  603685             浙江晨丰科技股份有限公司公开发行可转换公司债券
..      ...   ...  ...     ...                                 ...
391  123048  应急转债  ...  300527  中国船舶重工集团应急预警与救援装备股份有限公司公开发行可转换公司债券
392  128106  华统转债  ...  002840            浙江华统肉制品股份有限公司公开发行可转换公司债券
393  113575  东时转债  ...  603377           东方时尚驾驶学校股份有限公司公开发行可转换公司债券
394  127016  鲁泰转债  ...  000726               鲁泰纺织股份有限公司公开发行可转换公司债券
395  128105  长集转债  ...  002616           广东长青(集团)股份有限公司公开发行可转换公司债券
```

### 中债指数

#### 总指数

##### 综合类指数

###### 新综合指数

接口: bond_new_composite_index_cbond

目标地址: https://yield.chinabond.com.cn/cbweb-mn/indices/single_index_query

描述: 中国债券信息网-中债指数-中债指数族系-总指数-综合类指数-中债-新综合指数

输入参数

| 名称        | 类型  | 描述                                                                                                                                                                                                       |
|-----------|-----|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| indicator | str | indicator="财富"; choice of {"全价", "净价", "财富", "平均市值法久期", "平均现金流法久期", "平均市值法凸性", "平均现金流法凸性", "平均现金流法到期收益率", "平均市值法到期收益率", "平均基点价值", "平均待偿期", "平均派息率", "指数上日总市值", "财富指数涨跌幅", "全价指数涨跌幅", "净价指数涨跌幅", "现券结算量"} |
| period    | str | period="总值"; choice of {"总值", "1年以下", "1-3年", "3-5年", "5-7年", "7-10年", "10年以上", "0-3个月", "3-6个月", "6-9个月", "9-12个月", "0-6个月", "6-12个月"}                                                                  |

输出参数

| 名称    | 类型      | 描述   |
|-------|---------|------|
| date  | object  | -    |
| value | float64 | 注意单位 |

接口示例

```python
import akshare as ak

bond_new_composite_index_cbond_df = ak.bond_new_composite_index_cbond(indicator="财富", period="总值")
print(bond_new_composite_index_cbond_df)
```

数据示例

```
            date     value
0     2002-01-03   99.9731
1     2002-01-06  100.0149
2     2002-01-07   99.8273
3     2002-01-08  100.0203
4     2002-01-09   99.9317
          ...       ...
5179  2022-09-13  219.8213
5180  2022-09-14  219.8532
5181  2022-09-15  219.7886
5182  2022-09-18  219.8307
5183  2022-09-19  219.8963
```

###### 综合指数

接口: bond_composite_index_cbond

目标地址: https://yield.chinabond.com.cn/cbweb-mn/indices/single_index_query

描述: 中国债券信息网-中债指数-中债指数族系-总指数-综合类指数-中债-综合指数

输入参数

| 名称        | 类型  | 描述                                                                                                                                                                                                       |
|-----------|-----|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| indicator | str | indicator="财富"; choice of {"全价", "净价", "财富", "平均市值法久期", "平均现金流法久期", "平均市值法凸性", "平均现金流法凸性", "平均现金流法到期收益率", "平均市值法到期收益率", "平均基点价值", "平均待偿期", "平均派息率", "指数上日总市值", "财富指数涨跌幅", "全价指数涨跌幅", "净价指数涨跌幅", "现券结算量"} |
| period    | str | period="总值"; choice of {"总值", "1年以下", "1-3年", "3-5年", "5-7年", "7-10年", "10年以上", "0-3个月", "3-6个月", "6-9个月", "9-12个月", "0-6个月", "6-12个月"}                                                                  |

输出参数

| 名称    | 类型      | 描述   |
|-------|---------|------|
| date  | object  | -    |
| value | float64 | 注意单位 |

接口示例

```python
import akshare as ak

bond_composite_index_cbond_df = ak.bond_composite_index_cbond(indicator="财富", period="总值")
print(bond_composite_index_cbond_df)
```

数据示例

```
            date     value
0     2002-01-03   99.9731
1     2002-01-06  100.0149
2     2002-01-07   99.8273
3     2002-01-08  100.0203
4     2002-01-09   99.9317
          ...       ...
5179  2022-09-13  225.3442
5180  2022-09-14  225.3768
5181  2022-09-15  225.3106
5182  2022-09-18  225.3538
5183  2022-09-19  225.4211
```
